@@ -1,6 +1,5 @@
 /*
- *  Copyright (C) 2020 Team Kodi
- *  https://kodi.tv
+ *  Copyright (C) 2020-2021 Team Kodi (https://kodi.tv)
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  *  See LICENSE.md for more information.
@@ -344,7 +343,12 @@ bool Recordings::UpdatePvrRecording(const tinyxml2::XMLNode* pRecordingNode, kod
   std::string recordingFile;
   if (XMLUtils::GetString(pRecordingNode, "file", recordingFile))
   {
-    if (m_settings.m_showRecordingSize)
+    int64_t filesize = 0;
+    if (XMLUtils::GetLong(pRecordingNode, "size", filesize))
+    {
+      tag.SetSizeInBytes(filesize);
+    }
+    else if (m_settings.m_showRecordingSize)
     {
       kodi::tools::StringUtils::Replace(recordingFile, '\\', '/');
       if (kodi::tools::StringUtils::StartsWith(recordingFile, "//"))
@@ -384,10 +388,17 @@ bool Recordings::UpdatePvrRecording(const tinyxml2::XMLNode* pRecordingNode, kod
     }
     else
     {
-      if (m_settings.m_sendSidWithMetadata)
-        artworkPath = kodi::tools::StringUtils::Format("%s/service?method=channel.show.artwork&sid=%s&name=%s", m_settings.m_urlBase, m_request.GetSID(), UriEncode(title).c_str());
+      std::string name;
+      buffer.clear();
+      if (XMLUtils::GetString(pRecordingNode, "group", buffer))
+          name = UriEncode(buffer);
       else
-        artworkPath = kodi::tools::StringUtils::Format("%s/service?method=channel.show.artwork&name=%s", m_settings.m_urlBase, UriEncode(title).c_str());
+          name = UriEncode(title);
+
+      if (m_settings.m_sendSidWithMetadata)
+        artworkPath = kodi::tools::StringUtils::Format("%s/service?method=channel.show.artwork&sid=%s&name=%s", m_settings.m_urlBase, m_request.GetSID(), name.c_str());
+      else
+        artworkPath = kodi::tools::StringUtils::Format("%s/service?method=channel.show.artwork&name=%s", m_settings.m_urlBase, name.c_str());
       tag.SetFanartPath(artworkPath);
       artworkPath += "&prefer=poster";
       tag.SetThumbnailPath(artworkPath);
@@ -420,7 +431,7 @@ bool Recordings::ParseNextPVRSubtitle(const tinyxml2::XMLNode *pRecordingNode, k
   bool hasSeasonEpisode = false;
   if (XMLUtils::GetString(pRecordingNode, "subtitle", buffer))
   {
-    std::regex base_regex("S(\\d\\d)E(\\d+) - ?(.+)?");
+    std::regex base_regex("S(\\d{2,4})E(\\d+) - ?(.+)?");
     std::smatch base_match;
     // note NextPVR does not support S0 for specials
     if (std::regex_match(buffer, base_match, base_regex))
@@ -454,7 +465,7 @@ bool Recordings::ParseNextPVRSubtitle(const tinyxml2::XMLNode *pRecordingNode, k
     std::string recordingFile;
     if (XMLUtils::GetString(pRecordingNode, "file", recordingFile))
     {
-      std::regex base_regex("S(\\d\\d)E(\\d+)");
+      std::regex base_regex("S(\\d{2,4})E(\\d+)");
       std::smatch base_match;
       if (std::regex_search(recordingFile, base_match, base_regex))
       {
@@ -602,11 +613,20 @@ PVR_ERROR Recordings::GetRecordingEdl(const kodi::addon::PVRRecording& recording
   tinyxml2::XMLDocument doc;
   if (m_request.DoMethodRequest(request, doc) == tinyxml2::XML_SUCCESS)
   {
-    int index = 0;
+    int numEDL = 0;
     tinyxml2::XMLNode* commercialsNode = doc.RootElement()->FirstChildElement("commercials");
     tinyxml2::XMLNode* pCommercialNode;
     for (pCommercialNode = commercialsNode->FirstChildElement("commercial"); pCommercialNode; pCommercialNode = pCommercialNode->NextSiblingElement())
     {
+      if (numEDL++ == PVR_ADDON_EDL_LENGTH)
+      {
+        /* PVR core stores EDL breaks in a hard-coded array in PVRClient.cpp PVR_EDL_ENTRY edl_array[PVR_ADDON_EDL_LENGTH];
+        * currently https://github.com/xbmc/xbmc/blob/master/xbmc/pvr/addons/PVRClient.cpp#L1056
+        * This check avoids overflowing this arrray */
+         
+        kodi::Log(ADDON_LOG_WARNING, "Maximum EDL entries reached");
+        break;
+      }
       kodi::addon::PVREDLEntry entry;
       std::string buffer;
       XMLUtils::GetString(pCommercialNode, "start", buffer);
