@@ -1,6 +1,5 @@
 /*
- *  Copyright (C) 2020 Team Kodi
- *  https://kodi.tv
+ *  Copyright (C) 2020-2021 Team Kodi (https://kodi.tv)
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  *  See LICENSE.md for more information.
@@ -217,6 +216,7 @@ PVR_ERROR Timers::GetTimers(kodi::addon::PVRTimersResultSet& results)
       results.Add(tag);
     }
     // next add the one-off recordings.
+    bool isRecordingUpdated = false;
     doc.Clear();
     if (m_request.DoMethodRequest("recording.list&filter=pending", doc) == tinyxml2::XML_SUCCESS)
     {
@@ -227,24 +227,33 @@ PVR_ERROR Timers::GetTimers(kodi::addon::PVRTimersResultSet& results)
         UpdatePvrTimer(pRecordingNode, tag);
         // pass timer to xbmc
         timerCount++;
+        if (tag.GetState() == PVR_TIMER_STATE_RECORDING)
+          isRecordingUpdated = true;
         results.Add(tag);
       }
     }
     doc.Clear();
     if (m_request.DoMethodRequest("recording.list&filter=conflict", doc) == tinyxml2::XML_SUCCESS)
     {
-      tinyxml2::XMLNode* recordingsNode = doc.RootElement()->FirstChildElement("recordings");
-      for (tinyxml2::XMLNode* pRecordingNode = recordingsNode->FirstChildElement("recording"); pRecordingNode; pRecordingNode = pRecordingNode->NextSiblingElement())
-      {
-        kodi::addon::PVRTimer tag;
-        UpdatePvrTimer(pRecordingNode, tag);
-        // pass timer to xbmc
-        timerCount++;
-        results.Add(tag);
-      }
-      m_iTimerCount = timerCount;
+     tinyxml2::XMLNode* recordingsNode = doc.RootElement()->FirstChildElement("recordings");
+     for (tinyxml2::XMLNode* pRecordingNode = recordingsNode->FirstChildElement("recording"); pRecordingNode; pRecordingNode = pRecordingNode->NextSiblingElement())
+     {
+       kodi::addon::PVRTimer tag;
+       UpdatePvrTimer(pRecordingNode, tag);
+       // pass timer to xbmc
+       timerCount++;
+       results.Add(tag);
+     }
+     m_iTimerCount = timerCount;
     }
-    m_lastTimerUpdateTime = time(nullptr);
+
+    if (isRecordingUpdated) {
+      g_pvrclient->TriggerRecordingUpdate();
+      m_lastTimerUpdateTime = time(nullptr);
+    } else if (g_pvrclient->m_nowPlaying == NotPlaying)
+      m_lastTimerUpdateTime = time(nullptr);
+    // else unknown recording state during playback
+
   }
   else
   {
@@ -412,9 +421,12 @@ PVR_ERROR Timers::GetTimerTypes(std::vector<kodi::addon::PVRTimerType>& types)
 
   /* PVR_Timer.iRecordingGroup values and presentation */
   static std::vector<kodi::addon::PVRTypeIntValue> recordingGroupValues;
-  for (unsigned int i = 0; i < m_settings.m_recordingDirectories.size(); ++i)
+  if (recordingGroupValues.size() == 0)
   {
-    recordingGroupValues.emplace_back(kodi::addon::PVRTypeIntValue(i, m_settings.m_recordingDirectories[i]));
+    for (unsigned int i = 0; i < m_settings.m_recordingDirectories.size(); ++i)
+    {
+      recordingGroupValues.emplace_back(kodi::addon::PVRTypeIntValue(i, m_settings.m_recordingDirectories[i]));
+    }
   }
 
   static const unsigned int TIMER_MANUAL_ATTRIBS
@@ -656,7 +668,7 @@ PVR_ERROR Timers::AddTimer(const kodi::addon::PVRTimer& timer)
 
   int marginStart = timer.GetMarginStart();
   int marginEnd = timer.GetMarginEnd();
-  if (m_settings.m_ignorePadding && timer.GetClientIndex() == PVR_TIMER_NO_CLIENT_INDEX && marginStart == 0 && marginStart == 0)
+  if (m_settings.m_ignorePadding && timer.GetClientIndex() == PVR_TIMER_NO_CLIENT_INDEX && marginStart == 0 && marginEnd == 0)
   {
     marginStart = m_settings.m_defaultPrePadding;
     marginEnd = m_settings.m_defaultPostPadding;
@@ -689,6 +701,23 @@ PVR_ERROR Timers::AddTimer(const kodi::addon::PVRTimer& timer)
       directory.c_str());
     break;
 
+  case TIMER_ONCE_EPG_CHILD:
+    kodi::Log(ADDON_LOG_DEBUG, "TIMER_ONCE_EPG_CHILD");
+    // build one-off recording request
+    if (m_settings.m_backendVersion < 50102)
+    {
+      kodi::Log(ADDON_LOG_ERROR, "Feature added in NextPVR 5.1.2");
+      return PVR_ERROR_REJECTED;
+    }
+    request = kodi::tools::StringUtils::Format("recording.save&recording_id=%d&recurring_id=%d&event_id=%d&pre_padding=%d&post_padding=%d&directory_id=%s",
+      timer.GetClientIndex(),
+      timer.GetParentClientIndex(),
+      epgOid,
+      marginStart,
+      marginEnd,
+      directory.c_str());
+    break;
+
   case TIMER_REPEATING_EPG:
     if (timer.GetClientChannelUid() == PVR_TIMER_ANY_CHANNEL)
     // Fake a manual recording not a specific type in NextPVR
@@ -811,6 +840,7 @@ PVR_ERROR Timers::AddTimer(const kodi::addon::PVRTimer& timer)
       g_pvrclient->TriggerRecordingUpdate();
 
     g_pvrclient->TriggerTimerUpdate();
+
     return PVR_ERROR_NO_ERROR;
   }
 
